# hdwretests.tcl---test scripts for low-level hardware debugging

#   Apr 26 1996  VP    TK version

# Wed Jan 25 17:30:37 GMT 1995, DB
#   substituted $env(EGHOME) for /eg

set debug 0
set started 0

set frame HDWRETESTS
set frametitle "Hardware Test Scripts"
set icontitle "HdWreTests"

if {[info exists env(VXIServer)] == 0} then {set vxiserver VXI}  \
   else {set vxiserver $env(VXIServer)}

set server $vxiserver

set directory "$env(EGHOME)/bin/test-scripts"
set selection {}
set dirlist {}

#    some simple register access procedures for people to use

proc wr {r v} {global server; EG "register :name '/$server/$r'  :value '$v'"}

proc wrs {r v} {global server; EG "register :pattern '/$server/$r'  :value '$v'"}

proc rr {r} {global server; EG "register :name '/$server/$r'  ?value"}

proc rrs {r} {global server; EG "register :pattern '/$server/$r'  ?names-and-values"}
   
proc irs {r} {global server; EG "register :pattern '/$server/$r'  !initialise"}

proc wa {r v} {global server; EG "register :name '/$server/$r'  :object '$v'"}



proc make-frame {} {
   global env

    :frame [self frame-name] :label "[self frame-title]" :show-footer T \
      :icon-name "[self icon-title]" :resize F

      :panel P1 :layout T :padx 10 :pady 10
         :layout H; :row-gap 0

         :text DIRECTORY :label "Directory:" :w 40
         :next-row T
         :hskip 200
         :button UP   :label Up
         :button DOWN :label Down

      :panel P2 :layout T :padx 10
         :list DIRECTORYLIST :exclusive T :rows 10 :cols 40

      :panel P3 :layout T :padx 10 :pady 10
         :layout H; :col-gap 10
         :button EXECUTE        :label "execute (tcl)"
         :button SHELL          :label "execute (csh)"
        :next-row T
         :button REDISPLAY  :label Redisplay
         :hskip 100
         :button HELP       :label Help...
      
      :show T
} 

proc click-execute {} {
   global dirlist selection directory
   if {[llength $selection]==0} then {
      set-footer "no script selected!!!"
      return
   }
   if {[llength $selection]>1} then {
      set-footer "multiple scripts selected!!!"
      return
   }
   set target [lindex $dirlist $selection]
   if {[string first d $target]==0} then {
      set-footer "can't execute a directory!!!"
      return
   }
   set target [lindex $dirlist $selection]
   if {[second $target]=="."} then {set-footer "can't execute `.'"; return}
   if {[second $target]==".."} then {set-footer "can't execute `.'"; return}
   set file [second $target]
   set-footer "executing $directory/$file..."
   set z [catch {source  $directory/$file} m]
   if {$z!=0} then {set-footer $m} else {clear-footer}
}


proc click-shell {} {
   global dirlist selection directory
   if {[llength $selection]==0} then {
      set-footer "no script selected!!!"
      return
   }
   if {[llength $selection]>1} then {
      set-footer "multiple scripts selected!!!"
      return
   }
   set target [lindex $dirlist $selection]
   if {[string first d $target]==0} then {
      set-footer "can't execute a directory!!!"
      return
   }
   set target [lindex $dirlist $selection]
   if {[second $target]=="."} then {set-footer "can't execute `.'"; return}
   if {[second $target]==".."} then {set-footer "can't execute `.'"; return}
   set file [second $target]
   set-footer "calling csh to execute $directory/$file..."
   set z [catch {exec /bin/csh -fc $directory/$file > /dev/tty} m]
   if {$z!=0} then {set-footer $m} else {clear-footer}
}

proc click-help {} {send mb goto [transparent "Engineering Tests"]}

proc click-directory name {
   global directory
   set directory $name
   click-redisplay
}

proc click-list {c s} {
   global debug selection dirlist
   if {$debug} then {puts stderr "click-list called with %$c%   %$s%"}
   set selection {}
   switch $c {
     :list-select {
        set i [lsearch $dirlist $s]
        lappend selection $i
     }
     :list-deselect {}
  }          
}

proc click-redisplay {} {
   global directory dirlist selection
   :modify DIRECTORY :value "$directory"
   set dirlist [format-directorylist [read-directory $directory] 1]
   paint-directory $directory 1
   set selection {}
}

proc click-up {} {
  global directory
  set directory [directory-up $directory]
  click-redisplay
}

proc click-down {} {
  global directory selection
  set directory [directory-down $directory $selection]
  click-redisplay
}

proc click arg {
   global debug
   if {$debug} then {puts stderr "click with argument \{$arg\}"}
   set f [lindex $arg 0]
   set c [lindex $arg 1]
   set w [lindex $arg 2]
   set v [lindex $arg 3]
   clear-footer 
   if {$c==":quit"} then {click-quit; return}
   switch $w {
      DIRECTORY     {click-directory $v}
      DIRECTORYLIST {click-list $c $v}
      UP            {click-up}
      DOWN          {click-down}
      EXECUTE       {click-execute}
      SHELL         {click-shell}
      HELP          {click-help}
      REDISPLAY     {click-redisplay}
      default       {puts stdout $arg}
   }
}


proc start args {
  global started

   if {$started != 0} then {open-frame} else {
     set started 1
     make-frame
     click-redisplay
   }
}

proc click-quit {} {close-frame}

proc finish args {global started; destroy-frame; set started 0}

