#    vxihistory.tcl   -     VXI card history frame


set debug 0
set started 0

set frame VXIHISTORY
set frametitle "VXI Card History"
set icontitle  "VXIH"

#    load definition list
loadsource vxihistory.defn

set HISTORYBASE [file join $env(EXPERIMENTDIR) VXIhistory]

set cardchoice {}
set filechoice {}
foreach item $moduledefinition {
     append cardchoice " " \"[first $item]\"
     append filechoice " [second $item]"
}

set cardindex 0
set card [lindex $cardchoice $cardindex]

set cardID 0
set file ""


loadsource common.vxi

proc get_text {w} {
   global _variable
   set v [string tolower $w]
   set _variable($v) "[[:path $w].text get 1.0 end]"
}

proc click-default {w v i} {
   global HISTORYBASE file

   switch -glob $w {

      CHANNEL   {click-channel $v}
      CARD      {click-card $v}
      FILE      {set file $v}
      DIRECTORY {set HISTORYBASE $v}
   }
}

proc click-card {i} {
   global cardchoice cardindex card

   set cardindex $i
   set card [lindex $cardchoice $cardindex]
   click-channel 0
}

proc click-channel {i} {
   global filechoice cardindex cardID file

   set cardID $i
   set file [file join [lindex $filechoice $cardindex]$cardID]
   :modify FILE :value $file
}

proc click-read {} {
   global HISTORYBASE file

   set ff [file join $HISTORYBASE $file]

   if {![file exists $ff]} then {
       if {[midas-confirmation "History file $ff does not exist - do you wish to create it?"] == 0} then {return}

#  create and write null file
       set z [catch {open $ff w} f]
       if {$z != 0} then {midas-warning "Unable to create file $ff\n$f"; return}
       close $f
   }

#  read history file

   set z [catch {open $ff r} f]
   if {$z != 0} then {midas-warning "Unable to read file $ff\n$f"; return}
   set h [read $f]
   close $f

#    and insert into the window

   :modify G :empty T :strings "$h"
}

proc click-write {} {
   global HISTORYBASE file

   set ff [file join $HISTORYBASE $file]

   if {![file exists $ff]} then {
       if {[midas-confirmation "History file $ff does not exist - do you wish to create it?"] == 0} then {return}

#  create and write null file
       set z [catch {open $ff w} f]
       if {$z != 0} then {midas-warning "Unable to create file $ff\n$f"; return}
       close $f
   }

#  write history file

   set z [catch {open $ff w} f]
   if {$z != 0} then {midas-warning "Unable to write file $ff\n$f"; return}
   puts $f [get_text G]
   close $f
}


proc make-frame {} {
   global env
   global cardchoice HISTORYBASE

   set frametitle "VXI Card History Frame"

      :frame [self frame-name] :label "[self frame-title]" :show-footer T  :resize F \
         :icon-image "@$env(ICONHOME)/vxi_crate" \
         :icon-name "[self icon-title]"

      :panel P1  :layout T :padx 10 :pady 10 
        :layout H; :col-gap 20; :row-gap 20
        :choice-stack CARD :label "Choose VXI Card Type:" :strings $cardchoice :value 0
        :number CHANNEL    :label "Choose VXI Card ID:"   :min 0  :max 50 :w 3 :value 0
        :next-row T
        :text DIRECTORY  :label "History file dirctory" :value $HISTORYBASE :w 40
        :text FILE       :label "Current History file"  :value "" :w 20

      :panel P2  :layout T :padx 10 :pady 10 
        :galley G :rows 30 :cols 80 :strings "" :font fixed

      :panel CLICK :layout B :padx 10 :pady 5 :after FOOTER
        :layout H; :row-gap 5; :col-gap 5
        :button READ  :label "Read History file"  :command click-read
        :button WRITE :label "Write History file" :command click-write
        :hskip 50
        :button HELP

   :show T
}

proc start args {
   global started cardindex
   if {$started == 0} then {
      make-frame
      set started 1
   }
   open-frame
   click-card $cardindex
}

